#!/bin/bash
#
#   INSTALL.sh   : Installation for FJSVfefpcl
#   version      : 2.2.0
#   author       : Yu Xinghai
#
#   Copyright FUJITSU LIMITED 2010-2012
#
#**************************************************************************
LANG=C; export LANG
LC_ALL=C; export LC_ALL

#-------------------------------------------------------------------------
# Environment definition
#-------------------------------------------------------------------------
DIRNAME="/usr/bin/dirname"
BASENAME="/bin/basename"
UNAME="/bin/uname"
GREP="/bin/grep"
FIND="/usr/bin/find"
SED="/bin/sed"
RPM="/bin/rpm"
AWK="/bin/awk"
DMIDECODE="/usr/sbin/dmidecode"

BASEDIR=$(cd `$DIRNAME $0` && /bin/pwd)
SHNAME=`$BASENAME $0`

UNAMEM="`$UNAME -m`"

IDXCOM=0
IDXDEF=1

MSGLOG="/tmp/postsetup.log"
MSGID="FJSVfefpcl"

#-------------------------------------------------------------------------
# sub routine
#-------------------------------------------------------------------------
logmsg() {
    echo "$*" >> $MSGLOG
}


#-------------------------------------------------------------------------
# main routine
#-------------------------------------------------------------------------
#
# su ?
#
if [ $EUID != 0 ]; then
#    logmsg "$SHNAME: not privileged."
    exit 1
fi

#
# Machine-type check
#

if [ ! -e "$DMIDECODE" ];then
        logmsg "$MSGID: Command dmidecode not found."
        logmsg "$MSGID: install failed."
        exit 1;
fi

MACHINE_NAME=$($DMIDECODE -t 1 | $AWK -F: '$1 ~ /Product Name$/ { print substr($2, match($2, /[[:alpha:]]/))}')

case $MACHINE_NAME in
        PRIMEQUEST*)
                ;;
        *)
                logmsg "$MSGID: Server type is not PRIMEQUEST, install canceled."
                logmsg "$MSGID: install completed."
                exit 0
                ;;
esac

#
# check argument
#
case $# in
  0)
    ;;
  *)
    logmsg "$MSGID: Illegal option."
    logmsg "$MSGID: Usage: $SHNAME"
    exit 1
    ;;
esac


#
# check rpm files
#
if [ $UNAMEM != "x86_64" -a $UNAMEM != "i686" ]; then
    logmsg "$MSGID: $UNAMEM is not supported."
    logmsg "$MSGID: install failed."
    exit 1
fi
for ent in $($FIND $BASEDIR | $GREP "\.$UNAMEM\."); do
    $BASENAME $ent | $GREP "\-kmod-common-" > /dev/null 2>&1
    if [ $? -eq 0 ]; then
        COMM_FP="`echo $ent | $GREP "\-kmod-common-"`"
        continue;
    fi
    # default(Intel64) or PAE(x86)
    KMODDEF_FP="`echo $ent`"
done

FPRPM=($COMM_FP $KMODDEF_FP)
NMRPM=()
NMVL=()
NMPKG=()
for idx in $IDXCOM $IDXDEF ; do
    NMRPM=(${NMRPM[@]} `$BASENAME ${FPRPM[$idx]}`)
    NMVL=(${NMVL[@]} `echo ${NMRPM[$idx]} | $SED -n "s/\.[^\.]*\.rpm$//p"`)
    NMPKG=(${NMPKG[@]} `$RPM -qp --qf '%{NAME}\n' ${FPRPM[$idx]}`)
done


#
# if older version and necessary-to-be-replaced one is installed, 
# remove old one.
#
INSTALLED=(0 0)
for idx in $IDXCOM $IDXDEF ; do
    $RPM -q ${NMPKG[$idx]} > /dev/null 2>&1
    if [ $? -eq 0 ]; then
        INSTALLED[$idx]=1
        $RPM -Uvh --test --nodeps ${FPRPM[$idx]} > /dev/null 2>&1
        if [ $? -eq 0 ]; then
            INSTALLED[$idx]=2
        fi
    fi
done


if [ ${INSTALLED[$IDXCOM]} -ge 1 -o ${INSTALLED[$IDXDEF]} -ge 1 ]; then
    if [ ${INSTALLED[$IDXCOM]} -eq 1 -a ${INSTALLED[$IDXDEF]} -eq 1 ]; then
        logmsg "$MSGID: The same or newer version one is already installed, so updating skipped."
        logmsg "$MSGID: install completed."
        exit 0
    fi
    logmsg "$MSGID: Remove old package."
    $BASEDIR/UNINSTALL.sh >> $MSGLOG 2>&1
    if [ $? -ne 0 ]; then
        logmsg "$MSGID: install failed."
        exit 1
    fi
fi


#
# install package
#
for idx in $IDXCOM $IDXDEF ; do
    $RPM -ivh ${FPRPM[$idx]} >> $MSGLOG 2>&1
    if [ $? -ne 0 ]; then
        logmsg "$MSGID: Fatal error: Cannot install ${NMRPM[$idx]}."
        logmsg "$MSGID: install failed."
        exit 1
    else
        logmsg "$MSGID: ${NMRPM[$idx]} install completed."
    fi
done

logmsg "$MSGID: install completed."
exit 0
